/**
 * @author SrinivasJasti
 * 
 */
package org.srinivas.siteworks.controllers;

import static org.srinivas.siteworks.ViewConfiguration.REPORTCONTROLLER_JASPER_REPORT_DATASOURCE;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import net.sf.jasperreports.engine.JRDataSource;
import net.sf.jasperreports.engine.data.JRBeanCollectionDataSource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.ModelAndView;
import org.srinivas.siteworks.ReportBean;

@Controller
@RequestMapping(value = "/jasperreport")
public class JasperReportsController {

	public static final String REPORTCONTROLLER_REPORT_TYPE_BEAN_NAME_XLS_REPORT = "xlsReport";
	public static final String REPORTCONTROLLER_REPORT_TYPE_BEAN_NAME_PDF_REPORT = "pdfReport";	
	public static final String STRING_MESSAGE_WELCOME_TO_WEB_APPLICATION_INITIALISER_INTEGRATED_WITH_JASPER_REPORTS = "Welcome to WebApplication Initialiser Integrated with JasperReports Page";
	private static final Logger logger = LoggerFactory.getLogger(JasperReportsController.class);

	/**
	 * Report page.
	 * @param model the model
	 * @return the string
	 */
	@RequestMapping(method = RequestMethod.GET)
	public String reportPage(Model model) {
		logger.info("JasperReportsController");
		model.addAttribute("message", STRING_MESSAGE_WELCOME_TO_WEB_APPLICATION_INITIALISER_INTEGRATED_WITH_JASPER_REPORTS);
		return "jasperreport";
	}

	/**
	 * Generate pdf report. 
	 * @param modelAndView the model and view
	 * @return the model and view
	 */
	@RequestMapping(value = "/pdf", method = RequestMethod.GET)
	public ModelAndView generatePdfReport(ModelAndView modelAndView) {
		logger.info("ReportController generatePdfReport Method");
		Map<String, Object> parameterMap = new HashMap<String, Object>();
		List<ReportBean> dataList = new ArrayList<ReportBean>();
		dataList.add(createReportData());
		JRDataSource JRdataSource = new JRBeanCollectionDataSource(dataList);
		parameterMap.put(REPORTCONTROLLER_JASPER_REPORT_DATASOURCE, JRdataSource);
		logger.info("rendering the pdf view");
		modelAndView = new ModelAndView(REPORTCONTROLLER_REPORT_TYPE_BEAN_NAME_PDF_REPORT, parameterMap);
		return modelAndView;
	}

	/**
	 * Generate xls report. 
	 * @param modelAndView the model and view
	 * @return the model and view
	 */
	@RequestMapping(value = "/xls", method = RequestMethod.GET)
	public ModelAndView generateXlsReport(ModelAndView modelAndView) {
		logger.info("ReportController generateXlsReport Method");
		Map<String, Object> parameterMap = new HashMap<String, Object>();
		List<ReportBean> dataList = new ArrayList<ReportBean>();
		dataList.add(createReportData());
		JRDataSource JRdataSource = new JRBeanCollectionDataSource(dataList);
		parameterMap.put(REPORTCONTROLLER_JASPER_REPORT_DATASOURCE, JRdataSource);
		logger.info("rendering the xls view");
		modelAndView = new ModelAndView(REPORTCONTROLLER_REPORT_TYPE_BEAN_NAME_XLS_REPORT, parameterMap);
		return modelAndView;
	}

	/**
	 * Creates the report data. 
	 * @return the report bean
	 */
	public ReportBean createReportData() {
		ReportBean reportBean = new ReportBean();
		reportBean.setFirstName("Srinivas");
		reportBean.setLastName("Jasti");
		reportBean.setEmailAddress("srinivas.jasti@techbrightworks.com");
		reportBean.setCreatedDate(new Date());
		return reportBean;
	}

}
